@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2016, Adrian Sampson.
 #
@@ -15,10 +14,8 @@
 
 """Tests for autotagging functionality.
 """
-from __future__ import division, absolute_import, print_function
 
 import re
-import copy
 import unittest
 
 from test import _common
@@ -87,25 +84,31 @@ class PluralityTest(_common.TestCase):
         fields = ['artist', 'album', 'albumartist', 'year', 'disctotal',
                   'mb_albumid', 'label', 'catalognum', 'country', 'media',
                   'albumdisambig']
-        items = [Item(**dict((f, '%s_%s' % (f, i or 1)) for f in fields))
+        items = [Item(**{f: '{}_{}'.format(f, i or 1) for f in fields})
                  for i in range(5)]
         likelies, _ = match.current_metadata(items)
         for f in fields:
-            self.assertEqual(likelies[f], '%s_1' % f)
+            if isinstance(likelies[f], int):
+                self.assertEqual(likelies[f], 0)
+            else:
+                self.assertEqual(likelies[f], '%s_1' % f)
 
 
-def _make_item(title, track, artist=u'some artist'):
+def _make_item(title, track, artist='some artist'):
     return Item(title=title, track=track,
-                artist=artist, album=u'some album',
+                artist=artist, album='some album',
                 length=1,
                 mb_trackid='', mb_albumid='', mb_artistid='')
 
 
 def _make_trackinfo():
     return [
-        TrackInfo(u'one', None, artist=u'some artist', length=1, index=1),
-        TrackInfo(u'two', None, artist=u'some artist', length=1, index=2),
-        TrackInfo(u'three', None, artist=u'some artist', length=1, index=3),
+        TrackInfo(title='one', track_id=None, artist='some artist',
+                  length=1, index=1),
+        TrackInfo(title='two', track_id=None, artist='some artist',
+                  length=1, index=2),
+        TrackInfo(title='three', track_id=None, artist='some artist',
+                  length=1, index=3),
     ]
 
 
@@ -118,7 +121,7 @@ def _clear_weights():
 
 class DistanceTest(_common.TestCase):
     def tearDown(self):
-        super(DistanceTest, self).tearDown()
+        super().tearDown()
         _clear_weights()
 
     def test_add(self):
@@ -194,8 +197,8 @@ class DistanceTest(_common.TestCase):
 
     def test_add_string(self):
         dist = Distance()
-        sdist = string_dist(u'abc', u'bcd')
-        dist.add_string('string', u'abc', u'bcd')
+        sdist = string_dist('abc', 'bcd')
+        dist.add_string('string', 'abc', 'bcd')
         self.assertEqual(dist._penalties['string'], [sdist])
         self.assertNotEqual(dist._penalties['string'], [0])
 
@@ -300,27 +303,27 @@ class DistanceTest(_common.TestCase):
 
 class TrackDistanceTest(_common.TestCase):
     def test_identical_tracks(self):
-        item = _make_item(u'one', 1)
+        item = _make_item('one', 1)
         info = _make_trackinfo()[0]
         dist = match.track_distance(item, info, incl_artist=True)
         self.assertEqual(dist, 0.0)
 
     def test_different_title(self):
-        item = _make_item(u'foo', 1)
+        item = _make_item('foo', 1)
         info = _make_trackinfo()[0]
         dist = match.track_distance(item, info, incl_artist=True)
         self.assertNotEqual(dist, 0.0)
 
     def test_different_artist(self):
-        item = _make_item(u'one', 1)
-        item.artist = u'foo'
+        item = _make_item('one', 1)
+        item.artist = 'foo'
         info = _make_trackinfo()[0]
         dist = match.track_distance(item, info, incl_artist=True)
         self.assertNotEqual(dist, 0.0)
 
     def test_various_artists_tolerated(self):
-        item = _make_item(u'one', 1)
-        item.artist = u'Various Artists'
+        item = _make_item('one', 1)
+        item.artist = 'Various Artists'
         info = _make_trackinfo()[0]
         dist = match.track_distance(item, info, incl_artist=True)
         self.assertEqual(dist, 0.0)
@@ -338,30 +341,26 @@ class AlbumDistanceTest(_common.TestCase):
 
     def test_identical_albums(self):
         items = []
-        items.append(_make_item(u'one', 1))
-        items.append(_make_item(u'two', 2))
-        items.append(_make_item(u'three', 3))
+        items.append(_make_item('one', 1))
+        items.append(_make_item('two', 2))
+        items.append(_make_item('three', 3))
         info = AlbumInfo(
-            artist=u'some artist',
-            album=u'some album',
+            artist='some artist',
+            album='some album',
             tracks=_make_trackinfo(),
-            va=False,
-            album_id=None,
-            artist_id=None,
+            va=False
         )
         self.assertEqual(self._dist(items, info), 0)
 
     def test_incomplete_album(self):
         items = []
-        items.append(_make_item(u'one', 1))
-        items.append(_make_item(u'three', 3))
+        items.append(_make_item('one', 1))
+        items.append(_make_item('three', 3))
         info = AlbumInfo(
-            artist=u'some artist',
-            album=u'some album',
+            artist='some artist',
+            album='some album',
             tracks=_make_trackinfo(),
-            va=False,
-            album_id=None,
-            artist_id=None,
+            va=False
         )
         dist = self._dist(items, info)
         self.assertNotEqual(dist, 0)
@@ -370,47 +369,41 @@ class AlbumDistanceTest(_common.TestCase):
 
     def test_global_artists_differ(self):
         items = []
-        items.append(_make_item(u'one', 1))
-        items.append(_make_item(u'two', 2))
-        items.append(_make_item(u'three', 3))
+        items.append(_make_item('one', 1))
+        items.append(_make_item('two', 2))
+        items.append(_make_item('three', 3))
         info = AlbumInfo(
-            artist=u'someone else',
-            album=u'some album',
+            artist='someone else',
+            album='some album',
             tracks=_make_trackinfo(),
-            va=False,
-            album_id=None,
-            artist_id=None,
+            va=False
         )
         self.assertNotEqual(self._dist(items, info), 0)
 
     def test_comp_track_artists_match(self):
         items = []
-        items.append(_make_item(u'one', 1))
-        items.append(_make_item(u'two', 2))
-        items.append(_make_item(u'three', 3))
+        items.append(_make_item('one', 1))
+        items.append(_make_item('two', 2))
+        items.append(_make_item('three', 3))
         info = AlbumInfo(
-            artist=u'should be ignored',
-            album=u'some album',
+            artist='should be ignored',
+            album='some album',
             tracks=_make_trackinfo(),
-            va=True,
-            album_id=None,
-            artist_id=None,
+            va=True
         )
         self.assertEqual(self._dist(items, info), 0)
 
     def test_comp_no_track_artists(self):
         # Some VA releases don't have track artists (incomplete metadata).
         items = []
-        items.append(_make_item(u'one', 1))
-        items.append(_make_item(u'two', 2))
-        items.append(_make_item(u'three', 3))
+        items.append(_make_item('one', 1))
+        items.append(_make_item('two', 2))
+        items.append(_make_item('three', 3))
         info = AlbumInfo(
-            artist=u'should be ignored',
-            album=u'some album',
+            artist='should be ignored',
+            album='some album',
             tracks=_make_trackinfo(),
-            va=True,
-            album_id=None,
-            artist_id=None,
+            va=True
         )
         info.tracks[0].artist = None
         info.tracks[1].artist = None
@@ -419,47 +412,41 @@ class AlbumDistanceTest(_common.TestCase):
 
     def test_comp_track_artists_do_not_match(self):
         items = []
-        items.append(_make_item(u'one', 1))
-        items.append(_make_item(u'two', 2, u'someone else'))
-        items.append(_make_item(u'three', 3))
+        items.append(_make_item('one', 1))
+        items.append(_make_item('two', 2, 'someone else'))
+        items.append(_make_item('three', 3))
         info = AlbumInfo(
-            artist=u'some artist',
-            album=u'some album',
+            artist='some artist',
+            album='some album',
             tracks=_make_trackinfo(),
-            va=True,
-            album_id=None,
-            artist_id=None,
+            va=True
         )
         self.assertNotEqual(self._dist(items, info), 0)
 
     def test_tracks_out_of_order(self):
         items = []
-        items.append(_make_item(u'one', 1))
-        items.append(_make_item(u'three', 2))
-        items.append(_make_item(u'two', 3))
+        items.append(_make_item('one', 1))
+        items.append(_make_item('three', 2))
+        items.append(_make_item('two', 3))
         info = AlbumInfo(
-            artist=u'some artist',
-            album=u'some album',
+            artist='some artist',
+            album='some album',
             tracks=_make_trackinfo(),
-            va=False,
-            album_id=None,
-            artist_id=None,
+            va=False
         )
         dist = self._dist(items, info)
         self.assertTrue(0 < dist < 0.2)
 
     def test_two_medium_release(self):
         items = []
-        items.append(_make_item(u'one', 1))
-        items.append(_make_item(u'two', 2))
-        items.append(_make_item(u'three', 3))
+        items.append(_make_item('one', 1))
+        items.append(_make_item('two', 2))
+        items.append(_make_item('three', 3))
         info = AlbumInfo(
-            artist=u'some artist',
-            album=u'some album',
+            artist='some artist',
+            album='some album',
             tracks=_make_trackinfo(),
-            va=False,
-            album_id=None,
-            artist_id=None,
+            va=False
         )
         info.tracks[0].medium_index = 1
         info.tracks[1].medium_index = 2
@@ -469,16 +456,14 @@ class AlbumDistanceTest(_common.TestCase):
 
     def test_per_medium_track_numbers(self):
         items = []
-        items.append(_make_item(u'one', 1))
-        items.append(_make_item(u'two', 2))
-        items.append(_make_item(u'three', 1))
+        items.append(_make_item('one', 1))
+        items.append(_make_item('two', 2))
+        items.append(_make_item('three', 1))
         info = AlbumInfo(
-            artist=u'some artist',
-            album=u'some album',
+            artist='some artist',
+            album='some album',
             tracks=_make_trackinfo(),
-            va=False,
-            album_id=None,
-            artist_id=None,
+            va=False
         )
         info.tracks[0].medium_index = 1
         info.tracks[1].medium_index = 2
@@ -496,13 +481,13 @@ class AssignmentTest(unittest.TestCase):
 
     def test_reorder_when_track_numbers_incorrect(self):
         items = []
-        items.append(self.item(u'one', 1))
-        items.append(self.item(u'three', 2))
-        items.append(self.item(u'two', 3))
+        items.append(self.item('one', 1))
+        items.append(self.item('three', 2))
+        items.append(self.item('two', 3))
         trackinfo = []
-        trackinfo.append(TrackInfo(u'one', None))
-        trackinfo.append(TrackInfo(u'two', None))
-        trackinfo.append(TrackInfo(u'three', None))
+        trackinfo.append(TrackInfo(title='one'))
+        trackinfo.append(TrackInfo(title='two'))
+        trackinfo.append(TrackInfo(title='three'))
         mapping, extra_items, extra_tracks = \
             match.assign_items(items, trackinfo)
         self.assertEqual(extra_items, [])
@@ -515,13 +500,13 @@ class AssignmentTest(unittest.TestCase):
 
     def test_order_works_with_invalid_track_numbers(self):
         items = []
-        items.append(self.item(u'one', 1))
-        items.append(self.item(u'three', 1))
-        items.append(self.item(u'two', 1))
+        items.append(self.item('one', 1))
+        items.append(self.item('three', 1))
+        items.append(self.item('two', 1))
         trackinfo = []
-        trackinfo.append(TrackInfo(u'one', None))
-        trackinfo.append(TrackInfo(u'two', None))
-        trackinfo.append(TrackInfo(u'three', None))
+        trackinfo.append(TrackInfo(title='one'))
+        trackinfo.append(TrackInfo(title='two'))
+        trackinfo.append(TrackInfo(title='three'))
         mapping, extra_items, extra_tracks = \
             match.assign_items(items, trackinfo)
         self.assertEqual(extra_items, [])
@@ -534,12 +519,12 @@ class AssignmentTest(unittest.TestCase):
 
     def test_order_works_with_missing_tracks(self):
         items = []
-        items.append(self.item(u'one', 1))
-        items.append(self.item(u'three', 3))
+        items.append(self.item('one', 1))
+        items.append(self.item('three', 3))
         trackinfo = []
-        trackinfo.append(TrackInfo(u'one', None))
-        trackinfo.append(TrackInfo(u'two', None))
-        trackinfo.append(TrackInfo(u'three', None))
+        trackinfo.append(TrackInfo(title='one'))
+        trackinfo.append(TrackInfo(title='two'))
+        trackinfo.append(TrackInfo(title='three'))
         mapping, extra_items, extra_tracks = \
             match.assign_items(items, trackinfo)
         self.assertEqual(extra_items, [])
@@ -551,12 +536,12 @@ class AssignmentTest(unittest.TestCase):
 
     def test_order_works_with_extra_tracks(self):
         items = []
-        items.append(self.item(u'one', 1))
-        items.append(self.item(u'two', 2))
-        items.append(self.item(u'three', 3))
+        items.append(self.item('one', 1))
+        items.append(self.item('two', 2))
+        items.append(self.item('three', 3))
         trackinfo = []
-        trackinfo.append(TrackInfo(u'one', None))
-        trackinfo.append(TrackInfo(u'three', None))
+        trackinfo.append(TrackInfo(title='one'))
+        trackinfo.append(TrackInfo(title='three'))
         mapping, extra_items, extra_tracks = \
             match.assign_items(items, trackinfo)
         self.assertEqual(extra_items, [items[1]])
@@ -570,9 +555,9 @@ class AssignmentTest(unittest.TestCase):
         # A real-world test case contributed by a user.
         def item(i, length):
             return Item(
-                artist=u'ben harper',
-                album=u'burn to shine',
-                title=u'ben harper - Burn to Shine {0}'.format(i),
+                artist='ben harper',
+                album='burn to shine',
+                title=f'ben harper - Burn to Shine {i}',
                 track=i,
                 length=length,
                 mb_trackid='', mb_albumid='', mb_artistid='',
@@ -592,20 +577,21 @@ class AssignmentTest(unittest.TestCase):
         items.append(item(12, 186.45916150485752))
 
         def info(index, title, length):
-            return TrackInfo(title, None, length=length, index=index)
+            return TrackInfo(title=title, length=length,
+                             index=index)
         trackinfo = []
-        trackinfo.append(info(1, u'Alone', 238.893))
-        trackinfo.append(info(2, u'The Woman in You', 341.44))
-        trackinfo.append(info(3, u'Less', 245.59999999999999))
-        trackinfo.append(info(4, u'Two Hands of a Prayer', 470.49299999999999))
-        trackinfo.append(info(5, u'Please Bleed', 277.86599999999999))
-        trackinfo.append(info(6, u'Suzie Blue', 269.30599999999998))
-        trackinfo.append(info(7, u'Steal My Kisses', 245.36000000000001))
-        trackinfo.append(info(8, u'Burn to Shine', 214.90600000000001))
-        trackinfo.append(info(9, u'Show Me a Little Shame', 224.0929999999999))
-        trackinfo.append(info(10, u'Forgiven', 317.19999999999999))
-        trackinfo.append(info(11, u'Beloved One', 243.733))
-        trackinfo.append(info(12, u'In the Lord\'s Arms', 186.13300000000001))
+        trackinfo.append(info(1, 'Alone', 238.893))
+        trackinfo.append(info(2, 'The Woman in You', 341.44))
+        trackinfo.append(info(3, 'Less', 245.59999999999999))
+        trackinfo.append(info(4, 'Two Hands of a Prayer', 470.49299999999999))
+        trackinfo.append(info(5, 'Please Bleed', 277.86599999999999))
+        trackinfo.append(info(6, 'Suzie Blue', 269.30599999999998))
+        trackinfo.append(info(7, 'Steal My Kisses', 245.36000000000001))
+        trackinfo.append(info(8, 'Burn to Shine', 214.90600000000001))
+        trackinfo.append(info(9, 'Show Me a Little Shame', 224.0929999999999))
+        trackinfo.append(info(10, 'Forgiven', 317.19999999999999))
+        trackinfo.append(info(11, 'Beloved One', 243.733))
+        trackinfo.append(info(12, 'In the Lord\'s Arms', 186.13300000000001))
 
         mapping, extra_items, extra_tracks = \
             match.assign_items(items, trackinfo)
@@ -615,7 +601,7 @@ class AssignmentTest(unittest.TestCase):
             self.assertEqual(items.index(item), trackinfo.index(info))
 
 
-class ApplyTestUtil(object):
+class ApplyTestUtil:
     def _apply(self, info=None, per_disc_numbering=False, artist_credit=False):
         info = info or self.info
         mapping = {}
@@ -628,15 +614,15 @@ class ApplyTestUtil(object):
 
 class ApplyTest(_common.TestCase, ApplyTestUtil):
     def setUp(self):
-        super(ApplyTest, self).setUp()
+        super().setUp()
 
         self.items = []
         self.items.append(Item({}))
         self.items.append(Item({}))
         trackinfo = []
         trackinfo.append(TrackInfo(
-            u'oneNew',
-            u'dfa939ec-118c-4d0f-84a0-60f3d1e6522c',
+            title='oneNew',
+            track_id='dfa939ec-118c-4d0f-84a0-60f3d1e6522c',
             medium=1,
             medium_index=1,
             medium_total=1,
@@ -645,8 +631,8 @@ class ApplyTest(_common.TestCase, ApplyTestUtil):
             artist_sort='trackArtistSort',
         ))
         trackinfo.append(TrackInfo(
-            u'twoNew',
-            u'40130ed1-a27c-42fd-a328-1ebefb6caef4',
+            title='twoNew',
+            track_id='40130ed1-a27c-42fd-a328-1ebefb6caef4',
             medium=2,
             medium_index=1,
             index=2,
@@ -654,13 +640,13 @@ class ApplyTest(_common.TestCase, ApplyTestUtil):
         ))
         self.info = AlbumInfo(
             tracks=trackinfo,
-            artist=u'artistNew',
-            album=u'albumNew',
+            artist='artistNew',
+            album='albumNew',
             album_id='7edb51cb-77d6-4416-a23c-3a8c2994a2c7',
             artist_id='a6623d39-2d8e-4f70-8242-0a9553b91e50',
-            artist_credit=u'albumArtistCredit',
-            artist_sort=u'albumArtistSort',
-            albumtype=u'album',
+            artist_credit='albumArtistCredit',
+            artist_sort='albumArtistSort',
+            albumtype='album',
             va=False,
             mediums=2,
         )
@@ -746,13 +732,13 @@ class ApplyTest(_common.TestCase, ApplyTestUtil):
         self.assertEqual(self.items[1].albumtype, 'album')
 
     def test_album_artist_overrides_empty_track_artist(self):
-        my_info = copy.deepcopy(self.info)
+        my_info = self.info.copy()
         self._apply(info=my_info)
         self.assertEqual(self.items[0].artist, 'artistNew')
         self.assertEqual(self.items[1].artist, 'artistNew')
 
     def test_album_artist_overridden_by_nonempty_track_artist(self):
-        my_info = copy.deepcopy(self.info)
+        my_info = self.info.copy()
         my_info.tracks[0].artist = 'artist1!'
         my_info.tracks[1].artist = 'artist2!'
         self._apply(info=my_info)
@@ -774,7 +760,7 @@ class ApplyTest(_common.TestCase, ApplyTestUtil):
         self.assertEqual(self.items[1].artist_sort, 'albumArtistSort')
 
     def test_full_date_applied(self):
-        my_info = copy.deepcopy(self.info)
+        my_info = self.info.copy()
         my_info.year = 2013
         my_info.month = 12
         my_info.day = 18
@@ -789,7 +775,7 @@ class ApplyTest(_common.TestCase, ApplyTestUtil):
         self.items.append(Item(year=1, month=2, day=3))
         self.items.append(Item(year=4, month=5, day=6))
 
-        my_info = copy.deepcopy(self.info)
+        my_info = self.info.copy()
         my_info.year = 2013
         self._apply(info=my_info)
 
@@ -809,7 +795,7 @@ class ApplyTest(_common.TestCase, ApplyTestUtil):
         self.assertEqual(self.items[0].day, 3)
 
     def test_data_source_applied(self):
-        my_info = copy.deepcopy(self.info)
+        my_info = self.info.copy()
         my_info.data_source = 'MusicBrainz'
         self._apply(info=my_info)
 
@@ -818,33 +804,33 @@ class ApplyTest(_common.TestCase, ApplyTestUtil):
 
 class ApplyCompilationTest(_common.TestCase, ApplyTestUtil):
     def setUp(self):
-        super(ApplyCompilationTest, self).setUp()
+        super().setUp()
 
         self.items = []
         self.items.append(Item({}))
         self.items.append(Item({}))
         trackinfo = []
         trackinfo.append(TrackInfo(
-            u'oneNew',
-            u'dfa939ec-118c-4d0f-84a0-60f3d1e6522c',
-            artist=u'artistOneNew',
-            artist_id=u'a05686fc-9db2-4c23-b99e-77f5db3e5282',
+            title='oneNew',
+            track_id='dfa939ec-118c-4d0f-84a0-60f3d1e6522c',
+            artist='artistOneNew',
+            artist_id='a05686fc-9db2-4c23-b99e-77f5db3e5282',
             index=1,
         ))
         trackinfo.append(TrackInfo(
-            u'twoNew',
-            u'40130ed1-a27c-42fd-a328-1ebefb6caef4',
-            artist=u'artistTwoNew',
-            artist_id=u'80b3cf5e-18fe-4c59-98c7-e5bb87210710',
+            title='twoNew',
+            track_id='40130ed1-a27c-42fd-a328-1ebefb6caef4',
+            artist='artistTwoNew',
+            artist_id='80b3cf5e-18fe-4c59-98c7-e5bb87210710',
             index=2,
         ))
         self.info = AlbumInfo(
             tracks=trackinfo,
-            artist=u'variousNew',
-            album=u'albumNew',
+            artist='variousNew',
+            album='albumNew',
             album_id='3b69ea40-39b8-487f-8818-04b6eff8c21a',
             artist_id='89ad4ac3-39f7-470e-963a-56509c546377',
-            albumtype=u'compilation',
+            albumtype='compilation',
         )
 
     def test_album_and_track_artists_separate(self):
@@ -871,7 +857,7 @@ class ApplyCompilationTest(_common.TestCase, ApplyTestUtil):
         self.assertFalse(self.items[1].comp)
 
     def test_va_flag_sets_comp(self):
-        va_info = copy.deepcopy(self.info)
+        va_info = self.info.copy()
         va_info.va = True
         self._apply(info=va_info)
         self.assertTrue(self.items[0].comp)
@@ -880,77 +866,77 @@ class ApplyCompilationTest(_common.TestCase, ApplyTestUtil):
 
 class StringDistanceTest(unittest.TestCase):
     def test_equal_strings(self):
-        dist = string_dist(u'Some String', u'Some String')
+        dist = string_dist('Some String', 'Some String')
         self.assertEqual(dist, 0.0)
 
     def test_different_strings(self):
-        dist = string_dist(u'Some String', u'Totally Different')
+        dist = string_dist('Some String', 'Totally Different')
         self.assertNotEqual(dist, 0.0)
 
     def test_punctuation_ignored(self):
-        dist = string_dist(u'Some String', u'Some.String!')
+        dist = string_dist('Some String', 'Some.String!')
         self.assertEqual(dist, 0.0)
 
     def test_case_ignored(self):
-        dist = string_dist(u'Some String', u'sOME sTring')
+        dist = string_dist('Some String', 'sOME sTring')
         self.assertEqual(dist, 0.0)
 
     def test_leading_the_has_lower_weight(self):
-        dist1 = string_dist(u'XXX Band Name', u'Band Name')
-        dist2 = string_dist(u'The Band Name', u'Band Name')
+        dist1 = string_dist('XXX Band Name', 'Band Name')
+        dist2 = string_dist('The Band Name', 'Band Name')
         self.assertTrue(dist2 < dist1)
 
     def test_parens_have_lower_weight(self):
-        dist1 = string_dist(u'One .Two.', u'One')
-        dist2 = string_dist(u'One (Two)', u'One')
+        dist1 = string_dist('One .Two.', 'One')
+        dist2 = string_dist('One (Two)', 'One')
         self.assertTrue(dist2 < dist1)
 
     def test_brackets_have_lower_weight(self):
-        dist1 = string_dist(u'One .Two.', u'One')
-        dist2 = string_dist(u'One [Two]', u'One')
+        dist1 = string_dist('One .Two.', 'One')
+        dist2 = string_dist('One [Two]', 'One')
         self.assertTrue(dist2 < dist1)
 
     def test_ep_label_has_zero_weight(self):
-        dist = string_dist(u'My Song (EP)', u'My Song')
+        dist = string_dist('My Song (EP)', 'My Song')
         self.assertEqual(dist, 0.0)
 
     def test_featured_has_lower_weight(self):
-        dist1 = string_dist(u'My Song blah Someone', u'My Song')
-        dist2 = string_dist(u'My Song feat Someone', u'My Song')
+        dist1 = string_dist('My Song blah Someone', 'My Song')
+        dist2 = string_dist('My Song feat Someone', 'My Song')
         self.assertTrue(dist2 < dist1)
 
     def test_postfix_the(self):
-        dist = string_dist(u'The Song Title', u'Song Title, The')
+        dist = string_dist('The Song Title', 'Song Title, The')
         self.assertEqual(dist, 0.0)
 
     def test_postfix_a(self):
-        dist = string_dist(u'A Song Title', u'Song Title, A')
+        dist = string_dist('A Song Title', 'Song Title, A')
         self.assertEqual(dist, 0.0)
 
     def test_postfix_an(self):
-        dist = string_dist(u'An Album Title', u'Album Title, An')
+        dist = string_dist('An Album Title', 'Album Title, An')
         self.assertEqual(dist, 0.0)
 
     def test_empty_strings(self):
-        dist = string_dist(u'', u'')
+        dist = string_dist('', '')
         self.assertEqual(dist, 0.0)
 
     def test_solo_pattern(self):
         # Just make sure these don't crash.
-        string_dist(u'The ', u'')
-        string_dist(u'(EP)', u'(EP)')
-        string_dist(u', An', u'')
+        string_dist('The ', '')
+        string_dist('(EP)', '(EP)')
+        string_dist(', An', '')
 
     def test_heuristic_does_not_harm_distance(self):
-        dist = string_dist(u'Untitled', u'[Untitled]')
+        dist = string_dist('Untitled', '[Untitled]')
         self.assertEqual(dist, 0.0)
 
     def test_ampersand_expansion(self):
-        dist = string_dist(u'And', u'&')
+        dist = string_dist('And', '&')
         self.assertEqual(dist, 0.0)
 
     def test_accented_characters(self):
-        dist = string_dist(u'\xe9\xe1\xf1', u'ean')
+        dist = string_dist('\xe9\xe1\xf1', 'ean')
         self.assertEqual(dist, 0.0)
 
 
