@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2016, Adrian Sampson.
 #
@@ -15,7 +14,6 @@
 
 """Test file manipulation functionality of Item.
 """
-from __future__ import division, absolute_import, print_function
 
 import shutil
 import os
@@ -32,7 +30,7 @@ from beets.util import MoveOperation
 
 class MoveTest(_common.TestCase):
     def setUp(self):
-        super(MoveTest, self).setUp()
+        super().setUp()
 
         # make a temporary file
         self.path = join(self.temp_dir, b'temp.mp3')
@@ -73,7 +71,7 @@ class MoveTest(_common.TestCase):
         old_path = self.i.path
         self.assertExists(old_path)
 
-        self.i.artist = u'newArtist'
+        self.i.artist = 'newArtist'
         self.i.move()
         self.assertNotExists(old_path)
         self.assertNotExists(os.path.dirname(old_path))
@@ -86,6 +84,24 @@ class MoveTest(_common.TestCase):
         self.i.move(operation=MoveOperation.COPY)
         self.assertExists(self.path)
 
+    def test_reflink_arrives(self):
+        self.i.move(operation=MoveOperation.REFLINK_AUTO)
+        self.assertExists(self.dest)
+
+    def test_reflink_does_not_depart(self):
+        self.i.move(operation=MoveOperation.REFLINK_AUTO)
+        self.assertExists(self.path)
+
+    @unittest.skipUnless(_common.HAVE_REFLINK, "need reflink")
+    def test_force_reflink_arrives(self):
+        self.i.move(operation=MoveOperation.REFLINK)
+        self.assertExists(self.dest)
+
+    @unittest.skipUnless(_common.HAVE_REFLINK, "need reflink")
+    def test_force_reflink_does_not_depart(self):
+        self.i.move(operation=MoveOperation.REFLINK)
+        self.assertExists(self.path)
+
     def test_move_changes_path(self):
         self.i.move()
         self.assertEqual(self.i.path, util.normpath(self.dest))
@@ -102,6 +118,25 @@ class MoveTest(_common.TestCase):
         self.i.move()
         self.assertEqual(self.i.path, old_path)
 
+    def test_move_file_with_colon(self):
+        self.i.artist = 'C:DOS'
+        self.i.move()
+        self.assertIn('C_DOS', self.i.path.decode())
+
+    def test_move_file_with_multiple_colons(self):
+        print(beets.config['replace'])
+        self.i.artist = 'COM:DOS'
+        self.i.move()
+        self.assertIn('COM_DOS', self.i.path.decode())
+
+    def test_move_file_with_colon_alt_separator(self):
+        old = beets.config['drive_sep_replace']
+        beets.config["drive_sep_replace"] = '0'
+        self.i.artist = 'C:DOS'
+        self.i.move()
+        self.assertIn('C0DOS', self.i.path.decode())
+        beets.config["drive_sep_replace"] = old
+
     def test_read_only_file_copied_writable(self):
         # Make the source file read-only.
         os.chmod(self.path, 0o444)
@@ -195,10 +230,15 @@ class HelperTest(_common.TestCase):
         a = ['a', 'b', 'c']
         self.assertEqual(util.components(p), a)
 
+    def test_forward_slash(self):
+        p = br'C:\a\b\c'
+        a = br'C:/a/b/c'
+        self.assertEqual(util.path_as_posix(p), a)
+
 
 class AlbumFileTest(_common.TestCase):
     def setUp(self):
-        super(AlbumFileTest, self).setUp()
+        super().setUp()
 
         # Make library and item.
         self.lib = beets.library.Library(':memory:')
@@ -217,7 +257,7 @@ class AlbumFileTest(_common.TestCase):
         self.otherdir = os.path.join(self.temp_dir, b'testotherdir')
 
     def test_albuminfo_move_changes_paths(self):
-        self.ai.album = u'newAlbumName'
+        self.ai.album = 'newAlbumName'
         self.ai.move()
         self.ai.store()
         self.i.load()
@@ -226,7 +266,7 @@ class AlbumFileTest(_common.TestCase):
 
     def test_albuminfo_move_moves_file(self):
         oldpath = self.i.path
-        self.ai.album = u'newAlbumName'
+        self.ai.album = 'newAlbumName'
         self.ai.move()
         self.ai.store()
         self.i.load()
@@ -236,7 +276,7 @@ class AlbumFileTest(_common.TestCase):
 
     def test_albuminfo_move_copies_file(self):
         oldpath = self.i.path
-        self.ai.album = u'newAlbumName'
+        self.ai.album = 'newAlbumName'
         self.ai.move(operation=MoveOperation.COPY)
         self.ai.store()
         self.i.load()
@@ -244,6 +284,17 @@ class AlbumFileTest(_common.TestCase):
         self.assertTrue(os.path.exists(oldpath))
         self.assertTrue(os.path.exists(self.i.path))
 
+    @unittest.skipUnless(_common.HAVE_REFLINK, "need reflink")
+    def test_albuminfo_move_reflinks_file(self):
+        oldpath = self.i.path
+        self.ai.album = 'newAlbumName'
+        self.ai.move(operation=MoveOperation.REFLINK)
+        self.ai.store()
+        self.i.load()
+
+        self.assertTrue(os.path.exists(oldpath))
+        self.assertTrue(os.path.exists(self.i.path))
+
     def test_albuminfo_move_to_custom_dir(self):
         self.ai.move(basedir=self.otherdir)
         self.i.load()
@@ -253,7 +304,7 @@ class AlbumFileTest(_common.TestCase):
 
 class ArtFileTest(_common.TestCase):
     def setUp(self):
-        super(ArtFileTest, self).setUp()
+        super().setUp()
 
         # Make library and item.
         self.lib = beets.library.Library(':memory:')
@@ -282,7 +333,7 @@ class ArtFileTest(_common.TestCase):
     def test_art_moves_with_album(self):
         self.assertTrue(os.path.exists(self.art))
         oldpath = self.i.path
-        self.ai.album = u'newAlbum'
+        self.ai.album = 'newAlbum'
         self.ai.move()
         self.i.load()
 
@@ -310,7 +361,7 @@ class ArtFileTest(_common.TestCase):
         touch(newart)
         i2 = item()
         i2.path = self.i.path
-        i2.artist = u'someArtist'
+        i2.artist = 'someArtist'
         ai = self.lib.add_album((i2,))
         i2.move(operation=MoveOperation.COPY)
 
@@ -326,7 +377,7 @@ class ArtFileTest(_common.TestCase):
         touch(newart)
         i2 = item()
         i2.path = self.i.path
-        i2.artist = u'someArtist'
+        i2.artist = 'someArtist'
         ai = self.lib.add_album((i2,))
         i2.move(operation=MoveOperation.COPY)
         ai.set_art(newart)
@@ -340,7 +391,7 @@ class ArtFileTest(_common.TestCase):
         touch(newart)
         i2 = item()
         i2.path = self.i.path
-        i2.artist = u'someArtist'
+        i2.artist = 'someArtist'
         ai = self.lib.add_album((i2,))
         i2.move(operation=MoveOperation.COPY)
 
@@ -357,7 +408,7 @@ class ArtFileTest(_common.TestCase):
         touch(newart)
         i2 = item()
         i2.path = self.i.path
-        i2.artist = u'someArtist'
+        i2.artist = 'someArtist'
         ai = self.lib.add_album((i2,))
         i2.move(operation=MoveOperation.COPY)
 
@@ -381,7 +432,7 @@ class ArtFileTest(_common.TestCase):
         try:
             i2 = item()
             i2.path = self.i.path
-            i2.artist = u'someArtist'
+            i2.artist = 'someArtist'
             ai = self.lib.add_album((i2,))
             i2.move(operation=MoveOperation.COPY)
             ai.set_art(newart)
@@ -399,7 +450,7 @@ class ArtFileTest(_common.TestCase):
         oldartpath = self.lib.albums()[0].artpath
         self.assertExists(oldartpath)
 
-        self.ai.album = u'different_album'
+        self.ai.album = 'different_album'
         self.ai.store()
         self.ai.items()[0].move()
 
@@ -416,7 +467,7 @@ class ArtFileTest(_common.TestCase):
         oldartpath = self.lib.albums()[0].artpath
         self.assertExists(oldartpath)
 
-        self.i.album = u'different_album'
+        self.i.album = 'different_album'
         self.i.album_id = None  # detach from album
         self.i.move()
 
@@ -428,7 +479,7 @@ class ArtFileTest(_common.TestCase):
 
 class RemoveTest(_common.TestCase):
     def setUp(self):
-        super(RemoveTest, self).setUp()
+        super().setUp()
 
         # Make library and item.
         self.lib = beets.library.Library(':memory:')
@@ -489,7 +540,7 @@ class RemoveTest(_common.TestCase):
 # Tests that we can "delete" nonexistent files.
 class SoftRemoveTest(_common.TestCase):
     def setUp(self):
-        super(SoftRemoveTest, self).setUp()
+        super().setUp()
 
         self.path = os.path.join(self.temp_dir, b'testfile')
         touch(self.path)
@@ -502,12 +553,12 @@ class SoftRemoveTest(_common.TestCase):
         try:
             util.remove(self.path + b'XXX', True)
         except OSError:
-            self.fail(u'OSError when removing path')
+            self.fail('OSError when removing path')
 
 
 class SafeMoveCopyTest(_common.TestCase):
     def setUp(self):
-        super(SafeMoveCopyTest, self).setUp()
+        super().setUp()
 
         self.path = os.path.join(self.temp_dir, b'testfile')
         touch(self.path)
@@ -525,6 +576,12 @@ class SafeMoveCopyTest(_common.TestCase):
         self.assertExists(self.dest)
         self.assertExists(self.path)
 
+    @unittest.skipUnless(_common.HAVE_REFLINK, "need reflink")
+    def test_successful_reflink(self):
+        util.reflink(self.path, self.dest)
+        self.assertExists(self.dest)
+        self.assertExists(self.path)
+
     def test_unsuccessful_move(self):
         with self.assertRaises(util.FilesystemError):
             util.move(self.path, self.otherpath)
@@ -533,6 +590,11 @@ class SafeMoveCopyTest(_common.TestCase):
         with self.assertRaises(util.FilesystemError):
             util.copy(self.path, self.otherpath)
 
+    @unittest.skipUnless(_common.HAVE_REFLINK, "need reflink")
+    def test_unsuccessful_reflink(self):
+        with self.assertRaises(util.FilesystemError):
+            util.reflink(self.path, self.otherpath)
+
     def test_self_move(self):
         util.move(self.path, self.path)
         self.assertExists(self.path)
@@ -544,7 +606,7 @@ class SafeMoveCopyTest(_common.TestCase):
 
 class PruneTest(_common.TestCase):
     def setUp(self):
-        super(PruneTest, self).setUp()
+        super().setUp()
 
         self.base = os.path.join(self.temp_dir, b'testdir')
         os.mkdir(self.base)
@@ -564,7 +626,7 @@ class PruneTest(_common.TestCase):
 
 class WalkTest(_common.TestCase):
     def setUp(self):
-        super(WalkTest, self).setUp()
+        super().setUp()
 
         self.base = os.path.join(self.temp_dir, b'testdir')
         os.mkdir(self.base)
@@ -604,7 +666,7 @@ class WalkTest(_common.TestCase):
 
 class UniquePathTest(_common.TestCase):
     def setUp(self):
-        super(UniquePathTest, self).setUp()
+        super().setUp()
 
         self.base = os.path.join(self.temp_dir, b'testdir')
         os.mkdir(self.base)
