@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2016, Fabrice Laporte.
 #
@@ -15,7 +14,6 @@
 
 """Tests for the 'ftintitle' plugin."""
 
-from __future__ import division, absolute_import, print_function
 
 import unittest
 from test.helper import TestHelper
@@ -45,41 +43,41 @@ class FtInTitlePluginFunctional(unittest.TestCase, TestHelper):
         self.config['ftintitle']['auto'] = auto
 
     def test_functional_drop(self):
-        item = self._ft_add_item('/', u'Alice ft Bob', u'Song 1', u'Alice')
+        item = self._ft_add_item('/', 'Alice ft Bob', 'Song 1', 'Alice')
         self.run_command('ftintitle', '-d')
         item.load()
-        self.assertEqual(item['artist'], u'Alice')
-        self.assertEqual(item['title'], u'Song 1')
+        self.assertEqual(item['artist'], 'Alice')
+        self.assertEqual(item['title'], 'Song 1')
 
     def test_functional_not_found(self):
-        item = self._ft_add_item('/', u'Alice ft Bob', u'Song 1', u'George')
+        item = self._ft_add_item('/', 'Alice ft Bob', 'Song 1', 'George')
         self.run_command('ftintitle', '-d')
         item.load()
         # item should be unchanged
-        self.assertEqual(item['artist'], u'Alice ft Bob')
-        self.assertEqual(item['title'], u'Song 1')
+        self.assertEqual(item['artist'], 'Alice ft Bob')
+        self.assertEqual(item['title'], 'Song 1')
 
     def test_functional_custom_format(self):
         self._ft_set_config('feat. {0}')
-        item = self._ft_add_item('/', u'Alice ft Bob', u'Song 1', u'Alice')
+        item = self._ft_add_item('/', 'Alice ft Bob', 'Song 1', 'Alice')
         self.run_command('ftintitle')
         item.load()
-        self.assertEqual(item['artist'], u'Alice')
-        self.assertEqual(item['title'], u'Song 1 feat. Bob')
+        self.assertEqual(item['artist'], 'Alice')
+        self.assertEqual(item['title'], 'Song 1 feat. Bob')
 
         self._ft_set_config('featuring {0}')
-        item = self._ft_add_item('/', u'Alice feat. Bob', u'Song 1', u'Alice')
+        item = self._ft_add_item('/', 'Alice feat. Bob', 'Song 1', 'Alice')
         self.run_command('ftintitle')
         item.load()
-        self.assertEqual(item['artist'], u'Alice')
-        self.assertEqual(item['title'], u'Song 1 featuring Bob')
+        self.assertEqual(item['artist'], 'Alice')
+        self.assertEqual(item['title'], 'Song 1 featuring Bob')
 
         self._ft_set_config('with {0}')
-        item = self._ft_add_item('/', u'Alice feat Bob', u'Song 1', u'Alice')
+        item = self._ft_add_item('/', 'Alice feat Bob', 'Song 1', 'Alice')
         self.run_command('ftintitle')
         item.load()
-        self.assertEqual(item['artist'], u'Alice')
-        self.assertEqual(item['title'], u'Song 1 with Bob')
+        self.assertEqual(item['artist'], 'Alice')
+        self.assertEqual(item['title'], 'Song 1 with Bob')
 
 
 class FtInTitlePluginTest(unittest.TestCase):
@@ -149,33 +147,33 @@ class FtInTitlePluginTest(unittest.TestCase):
             self.assertEqual(feat_part, test_case['feat_part'])
 
     def test_split_on_feat(self):
-        parts = ftintitle.split_on_feat(u'Alice ft. Bob')
-        self.assertEqual(parts, (u'Alice', u'Bob'))
-        parts = ftintitle.split_on_feat(u'Alice feat Bob')
-        self.assertEqual(parts, (u'Alice', u'Bob'))
-        parts = ftintitle.split_on_feat(u'Alice feat. Bob')
-        self.assertEqual(parts, (u'Alice', u'Bob'))
-        parts = ftintitle.split_on_feat(u'Alice featuring Bob')
-        self.assertEqual(parts, (u'Alice', u'Bob'))
-        parts = ftintitle.split_on_feat(u'Alice & Bob')
-        self.assertEqual(parts, (u'Alice', u'Bob'))
-        parts = ftintitle.split_on_feat(u'Alice and Bob')
-        self.assertEqual(parts, (u'Alice', u'Bob'))
-        parts = ftintitle.split_on_feat(u'Alice With Bob')
-        self.assertEqual(parts, (u'Alice', u'Bob'))
-        parts = ftintitle.split_on_feat(u'Alice defeat Bob')
-        self.assertEqual(parts, (u'Alice defeat Bob', None))
+        parts = ftintitle.split_on_feat('Alice ft. Bob')
+        self.assertEqual(parts, ('Alice', 'Bob'))
+        parts = ftintitle.split_on_feat('Alice feat Bob')
+        self.assertEqual(parts, ('Alice', 'Bob'))
+        parts = ftintitle.split_on_feat('Alice feat. Bob')
+        self.assertEqual(parts, ('Alice', 'Bob'))
+        parts = ftintitle.split_on_feat('Alice featuring Bob')
+        self.assertEqual(parts, ('Alice', 'Bob'))
+        parts = ftintitle.split_on_feat('Alice & Bob')
+        self.assertEqual(parts, ('Alice', 'Bob'))
+        parts = ftintitle.split_on_feat('Alice and Bob')
+        self.assertEqual(parts, ('Alice', 'Bob'))
+        parts = ftintitle.split_on_feat('Alice With Bob')
+        self.assertEqual(parts, ('Alice', 'Bob'))
+        parts = ftintitle.split_on_feat('Alice defeat Bob')
+        self.assertEqual(parts, ('Alice defeat Bob', None))
 
     def test_contains_feat(self):
-        self.assertTrue(ftintitle.contains_feat(u'Alice ft. Bob'))
-        self.assertTrue(ftintitle.contains_feat(u'Alice feat. Bob'))
-        self.assertTrue(ftintitle.contains_feat(u'Alice feat Bob'))
-        self.assertTrue(ftintitle.contains_feat(u'Alice featuring Bob'))
-        self.assertTrue(ftintitle.contains_feat(u'Alice & Bob'))
-        self.assertTrue(ftintitle.contains_feat(u'Alice and Bob'))
-        self.assertTrue(ftintitle.contains_feat(u'Alice With Bob'))
-        self.assertFalse(ftintitle.contains_feat(u'Alice defeat Bob'))
-        self.assertFalse(ftintitle.contains_feat(u'Aliceft.Bob'))
+        self.assertTrue(ftintitle.contains_feat('Alice ft. Bob'))
+        self.assertTrue(ftintitle.contains_feat('Alice feat. Bob'))
+        self.assertTrue(ftintitle.contains_feat('Alice feat Bob'))
+        self.assertTrue(ftintitle.contains_feat('Alice featuring Bob'))
+        self.assertTrue(ftintitle.contains_feat('Alice & Bob'))
+        self.assertTrue(ftintitle.contains_feat('Alice and Bob'))
+        self.assertTrue(ftintitle.contains_feat('Alice With Bob'))
+        self.assertFalse(ftintitle.contains_feat('Alice defeat Bob'))
+        self.assertFalse(ftintitle.contains_feat('Aliceft.Bob'))
 
 
 def suite():
