@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2016, Fabrice Laporte.
 #
@@ -15,17 +14,15 @@
 
 """Tests for the 'lastgenre' plugin."""
 
-from __future__ import division, absolute_import, print_function
 
 import unittest
-from mock import Mock
+from unittest.mock import Mock
 
 from test import _common
 from beetsplug import lastgenre
 from beets import config
 
 from test.helper import TestHelper
-import six
 
 
 class LastGenrePluginTest(unittest.TestCase, TestHelper):
@@ -41,11 +38,11 @@ class LastGenrePluginTest(unittest.TestCase, TestHelper):
         config['lastgenre']['canonical'] = canonical
         config['lastgenre']['count'] = count
         config['lastgenre']['prefer_specific'] = prefer_specific
-        if isinstance(whitelist, (bool, six.string_types)):
+        if isinstance(whitelist, (bool, (str,))):
             # Filename, default, or disabled.
             config['lastgenre']['whitelist'] = whitelist
         self.plugin.setup()
-        if not isinstance(whitelist, (bool, six.string_types)):
+        if not isinstance(whitelist, (bool, (str,))):
             # Explicit list of genres.
             self.plugin.whitelist = whitelist
 
@@ -54,7 +51,7 @@ class LastGenrePluginTest(unittest.TestCase, TestHelper):
         """
         self._setup_config()
         self.assertEqual(self.plugin._resolve_genres(['delta blues']),
-                         u'Delta Blues')
+                         'Delta Blues')
 
     def test_c14n_only(self):
         """Default c14n tree funnels up to most common genre except for *wrong*
@@ -62,16 +59,16 @@ class LastGenrePluginTest(unittest.TestCase, TestHelper):
         """
         self._setup_config(canonical=True, count=99)
         self.assertEqual(self.plugin._resolve_genres(['delta blues']),
-                         u'Blues')
+                         'Blues')
         self.assertEqual(self.plugin._resolve_genres(['iota blues']),
-                         u'Iota Blues')
+                         'Iota Blues')
 
     def test_whitelist_only(self):
         """Default whitelist rejects *wrong* (non existing) genres.
         """
         self._setup_config(whitelist=True)
         self.assertEqual(self.plugin._resolve_genres(['iota blues']),
-                         u'')
+                         '')
 
     def test_whitelist_c14n(self):
         """Default whitelist and c14n both activated result in all parents
@@ -79,48 +76,48 @@ class LastGenrePluginTest(unittest.TestCase, TestHelper):
         """
         self._setup_config(canonical=True, whitelist=True, count=99)
         self.assertEqual(self.plugin._resolve_genres(['delta blues']),
-                         u'Delta Blues, Blues')
+                         'Delta Blues, Blues')
 
     def test_whitelist_custom(self):
         """Keep only genres that are in the whitelist.
         """
-        self._setup_config(whitelist=set(['blues', 'rock', 'jazz']),
+        self._setup_config(whitelist={'blues', 'rock', 'jazz'},
                            count=2)
         self.assertEqual(self.plugin._resolve_genres(['pop', 'blues']),
-                         u'Blues')
+                         'Blues')
 
-        self._setup_config(canonical='', whitelist=set(['rock']))
+        self._setup_config(canonical='', whitelist={'rock'})
         self.assertEqual(self.plugin._resolve_genres(['delta blues']),
-                         u'')
+                         '')
 
     def test_count(self):
         """Keep the n first genres, as we expect them to be sorted from more to
         less popular.
         """
-        self._setup_config(whitelist=set(['blues', 'rock', 'jazz']),
+        self._setup_config(whitelist={'blues', 'rock', 'jazz'},
                            count=2)
         self.assertEqual(self.plugin._resolve_genres(
                          ['jazz', 'pop', 'rock', 'blues']),
-                         u'Jazz, Rock')
+                         'Jazz, Rock')
 
     def test_count_c14n(self):
         """Keep the n first genres, after having applied c14n when necessary
         """
-        self._setup_config(whitelist=set(['blues', 'rock', 'jazz']),
+        self._setup_config(whitelist={'blues', 'rock', 'jazz'},
                            canonical=True,
                            count=2)
         # thanks to c14n, 'blues' superseeds 'country blues' and takes the
         # second slot
         self.assertEqual(self.plugin._resolve_genres(
                          ['jazz', 'pop', 'country blues', 'rock']),
-                         u'Jazz, Blues')
+                         'Jazz, Blues')
 
     def test_c14n_whitelist(self):
         """Genres first pass through c14n and are then filtered
         """
-        self._setup_config(canonical=True, whitelist=set(['rock']))
+        self._setup_config(canonical=True, whitelist={'rock'})
         self.assertEqual(self.plugin._resolve_genres(['delta blues']),
-                         u'')
+                         '')
 
     def test_empty_string_enables_canonical(self):
         """For backwards compatibility, setting the `canonical` option
@@ -128,7 +125,7 @@ class LastGenrePluginTest(unittest.TestCase, TestHelper):
         """
         self._setup_config(canonical='', count=99)
         self.assertEqual(self.plugin._resolve_genres(['delta blues']),
-                         u'Blues')
+                         'Blues')
 
     def test_empty_string_enables_whitelist(self):
         """Again for backwards compatibility, setting the `whitelist`
@@ -136,7 +133,7 @@ class LastGenrePluginTest(unittest.TestCase, TestHelper):
         """
         self._setup_config(whitelist='')
         self.assertEqual(self.plugin._resolve_genres(['iota blues']),
-                         u'')
+                         '')
 
     def test_prefer_specific_loads_tree(self):
         """When prefer_specific is enabled but canonical is not the
@@ -151,41 +148,41 @@ class LastGenrePluginTest(unittest.TestCase, TestHelper):
         self._setup_config(prefer_specific=True, canonical=False, count=4)
         self.assertEqual(self.plugin._resolve_genres(
                          ['math rock', 'post-rock']),
-                         u'Post-Rock, Math Rock')
+                         'Post-Rock, Math Rock')
 
     def test_no_duplicate(self):
         """Remove duplicated genres.
         """
         self._setup_config(count=99)
         self.assertEqual(self.plugin._resolve_genres(['blues', 'blues']),
-                         u'Blues')
+                         'Blues')
 
     def test_tags_for(self):
-        class MockPylastElem(object):
+        class MockPylastElem:
             def __init__(self, name):
                 self.name = name
 
             def get_name(self):
                 return self.name
 
-        class MockPylastObj(object):
+        class MockPylastObj:
             def get_top_tags(self):
                 tag1 = Mock()
                 tag1.weight = 90
-                tag1.item = MockPylastElem(u'Pop')
+                tag1.item = MockPylastElem('Pop')
                 tag2 = Mock()
                 tag2.weight = 40
-                tag2.item = MockPylastElem(u'Rap')
+                tag2.item = MockPylastElem('Rap')
                 return [tag1, tag2]
 
         plugin = lastgenre.LastGenrePlugin()
         res = plugin._tags_for(MockPylastObj())
-        self.assertEqual(res, [u'pop', u'rap'])
+        self.assertEqual(res, ['pop', 'rap'])
         res = plugin._tags_for(MockPylastObj(), min_weight=50)
-        self.assertEqual(res, [u'pop'])
+        self.assertEqual(res, ['pop'])
 
     def test_get_genre(self):
-        mock_genres = {'track': u'1', 'album': u'2', 'artist': u'3'}
+        mock_genres = {'track': '1', 'album': '2', 'artist': '3'}
 
         def mock_fetch_track_genre(self, obj=None):
             return mock_genres['track']
@@ -206,29 +203,29 @@ class LastGenrePluginTest(unittest.TestCase, TestHelper):
 
         config['lastgenre'] = {'force': False}
         res = self.plugin._get_genre(item)
-        self.assertEqual(res, (item.genre, u'keep'))
+        self.assertEqual(res, (item.genre, 'keep'))
 
-        config['lastgenre'] = {'force': True, 'source': u'track'}
+        config['lastgenre'] = {'force': True, 'source': 'track'}
         res = self.plugin._get_genre(item)
-        self.assertEqual(res, (mock_genres['track'], u'track'))
+        self.assertEqual(res, (mock_genres['track'], 'track'))
 
-        config['lastgenre'] = {'source': u'album'}
+        config['lastgenre'] = {'source': 'album'}
         res = self.plugin._get_genre(item)
-        self.assertEqual(res, (mock_genres['album'], u'album'))
+        self.assertEqual(res, (mock_genres['album'], 'album'))
 
-        config['lastgenre'] = {'source': u'artist'}
+        config['lastgenre'] = {'source': 'artist'}
         res = self.plugin._get_genre(item)
-        self.assertEqual(res, (mock_genres['artist'], u'artist'))
+        self.assertEqual(res, (mock_genres['artist'], 'artist'))
 
         mock_genres['artist'] = None
         res = self.plugin._get_genre(item)
-        self.assertEqual(res, (item.genre, u'original'))
+        self.assertEqual(res, (item.genre, 'original'))
 
-        config['lastgenre'] = {'fallback': u'rap'}
+        config['lastgenre'] = {'fallback': 'rap'}
         item.genre = None
         res = self.plugin._get_genre(item)
         self.assertEqual(res, (config['lastgenre']['fallback'].get(),
-                         u'fallback'))
+                         'fallback'))
 
     def test_sort_by_depth(self):
         self._setup_config(canonical=True)
