@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-
 """Stupid tests that ensure logging works as expected"""
-from __future__ import division, absolute_import, print_function
 
 import sys
 import threading
@@ -15,7 +12,6 @@ import beetsplug
 from test import _common
 from test._common import TestCase
 from test import helper
-import six
 
 
 class LoggingTest(TestCase):
@@ -46,13 +42,13 @@ class LoggingTest(TestCase):
         l.addHandler(handler)
         l.propagate = False
 
-        l.warning(u"foo {0} {bar}", "oof", bar=u"baz")
+        l.warning("foo {0} {bar}", "oof", bar="baz")
         handler.flush()
-        self.assertTrue(stream.getvalue(), u"foo oof baz")
+        self.assertTrue(stream.getvalue(), "foo oof baz")
 
 
 class LoggingLevelTest(unittest.TestCase, helper.TestHelper):
-    class DummyModule(object):
+    class DummyModule:
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
                 plugins.BeetsPlugin.__init__(self, 'dummy')
@@ -60,9 +56,9 @@ class LoggingLevelTest(unittest.TestCase, helper.TestHelper):
                 self.register_listener('dummy_event', self.listener)
 
             def log_all(self, name):
-                self._log.debug(u'debug ' + name)
-                self._log.info(u'info ' + name)
-                self._log.warning(u'warning ' + name)
+                self._log.debug('debug ' + name)
+                self._log.info('info ' + name)
+                self._log.warning('warning ' + name)
 
             def commands(self):
                 cmd = ui.Subcommand('dummy')
@@ -93,76 +89,76 @@ class LoggingLevelTest(unittest.TestCase, helper.TestHelper):
         self.config['verbose'] = 0
         with helper.capture_log() as logs:
             self.run_command('dummy')
-        self.assertIn(u'dummy: warning cmd', logs)
-        self.assertIn(u'dummy: info cmd', logs)
-        self.assertNotIn(u'dummy: debug cmd', logs)
+        self.assertIn('dummy: warning cmd', logs)
+        self.assertIn('dummy: info cmd', logs)
+        self.assertNotIn('dummy: debug cmd', logs)
 
     def test_command_level1(self):
         self.config['verbose'] = 1
         with helper.capture_log() as logs:
             self.run_command('dummy')
-        self.assertIn(u'dummy: warning cmd', logs)
-        self.assertIn(u'dummy: info cmd', logs)
-        self.assertIn(u'dummy: debug cmd', logs)
+        self.assertIn('dummy: warning cmd', logs)
+        self.assertIn('dummy: info cmd', logs)
+        self.assertIn('dummy: debug cmd', logs)
 
     def test_command_level2(self):
         self.config['verbose'] = 2
         with helper.capture_log() as logs:
             self.run_command('dummy')
-        self.assertIn(u'dummy: warning cmd', logs)
-        self.assertIn(u'dummy: info cmd', logs)
-        self.assertIn(u'dummy: debug cmd', logs)
+        self.assertIn('dummy: warning cmd', logs)
+        self.assertIn('dummy: info cmd', logs)
+        self.assertIn('dummy: debug cmd', logs)
 
     def test_listener_level0(self):
         self.config['verbose'] = 0
         with helper.capture_log() as logs:
             plugins.send('dummy_event')
-        self.assertIn(u'dummy: warning listener', logs)
-        self.assertNotIn(u'dummy: info listener', logs)
-        self.assertNotIn(u'dummy: debug listener', logs)
+        self.assertIn('dummy: warning listener', logs)
+        self.assertNotIn('dummy: info listener', logs)
+        self.assertNotIn('dummy: debug listener', logs)
 
     def test_listener_level1(self):
         self.config['verbose'] = 1
         with helper.capture_log() as logs:
             plugins.send('dummy_event')
-        self.assertIn(u'dummy: warning listener', logs)
-        self.assertIn(u'dummy: info listener', logs)
-        self.assertNotIn(u'dummy: debug listener', logs)
+        self.assertIn('dummy: warning listener', logs)
+        self.assertIn('dummy: info listener', logs)
+        self.assertNotIn('dummy: debug listener', logs)
 
     def test_listener_level2(self):
         self.config['verbose'] = 2
         with helper.capture_log() as logs:
             plugins.send('dummy_event')
-        self.assertIn(u'dummy: warning listener', logs)
-        self.assertIn(u'dummy: info listener', logs)
-        self.assertIn(u'dummy: debug listener', logs)
+        self.assertIn('dummy: warning listener', logs)
+        self.assertIn('dummy: info listener', logs)
+        self.assertIn('dummy: debug listener', logs)
 
     def test_import_stage_level0(self):
         self.config['verbose'] = 0
         with helper.capture_log() as logs:
             importer = self.create_importer()
             importer.run()
-        self.assertIn(u'dummy: warning import_stage', logs)
-        self.assertNotIn(u'dummy: info import_stage', logs)
-        self.assertNotIn(u'dummy: debug import_stage', logs)
+        self.assertIn('dummy: warning import_stage', logs)
+        self.assertNotIn('dummy: info import_stage', logs)
+        self.assertNotIn('dummy: debug import_stage', logs)
 
     def test_import_stage_level1(self):
         self.config['verbose'] = 1
         with helper.capture_log() as logs:
             importer = self.create_importer()
             importer.run()
-        self.assertIn(u'dummy: warning import_stage', logs)
-        self.assertIn(u'dummy: info import_stage', logs)
-        self.assertNotIn(u'dummy: debug import_stage', logs)
+        self.assertIn('dummy: warning import_stage', logs)
+        self.assertIn('dummy: info import_stage', logs)
+        self.assertNotIn('dummy: debug import_stage', logs)
 
     def test_import_stage_level2(self):
         self.config['verbose'] = 2
         with helper.capture_log() as logs:
             importer = self.create_importer()
             importer.run()
-        self.assertIn(u'dummy: warning import_stage', logs)
-        self.assertIn(u'dummy: info import_stage', logs)
-        self.assertIn(u'dummy: debug import_stage', logs)
+        self.assertIn('dummy: warning import_stage', logs)
+        self.assertIn('dummy: info import_stage', logs)
+        self.assertIn('dummy: debug import_stage', logs)
 
 
 @_common.slow_test()
@@ -183,9 +179,9 @@ class ConcurrentEventsTest(TestCase, helper.TestHelper):
             self.t1_step = self.t2_step = 0
 
         def log_all(self, name):
-            self._log.debug(u'debug ' + name)
-            self._log.info(u'info ' + name)
-            self._log.warning(u'warning ' + name)
+            self._log.debug('debug ' + name)
+            self._log.info('info ' + name)
+            self._log.warning('warning ' + name)
 
         def listener1(self):
             try:
@@ -220,7 +216,7 @@ class ConcurrentEventsTest(TestCase, helper.TestHelper):
 
         def check_dp_exc():
             if dp.exc_info:
-                six.reraise(dp.exc_info[1], None, dp.exc_info[2])
+                raise None.with_traceback(dp.exc_info[2])
 
         try:
             dp.lock1.acquire()
@@ -258,14 +254,14 @@ class ConcurrentEventsTest(TestCase, helper.TestHelper):
             self.assertFalse(t2.is_alive())
 
         except Exception:
-            print(u"Alive threads:", threading.enumerate())
+            print("Alive threads:", threading.enumerate())
             if dp.lock1.locked():
-                print(u"Releasing lock1 after exception in test")
+                print("Releasing lock1 after exception in test")
                 dp.lock1.release()
             if dp.lock2.locked():
-                print(u"Releasing lock2 after exception in test")
+                print("Releasing lock2 after exception in test")
                 dp.lock2.release()
-            print(u"Alive threads:", threading.enumerate())
+            print("Alive threads:", threading.enumerate())
             raise
 
     def test_root_logger_levels(self):
@@ -284,14 +280,14 @@ class ConcurrentEventsTest(TestCase, helper.TestHelper):
             importer = self.create_importer()
             importer.run()
         for l in logs:
-            self.assertIn(u"import", l)
-            self.assertIn(u"album", l)
+            self.assertIn("import", l)
+            self.assertIn("album", l)
 
         blog.getLogger('beets').set_global_level(blog.DEBUG)
         with helper.capture_log() as logs:
             importer = self.create_importer()
             importer.run()
-        self.assertIn(u"Sending event: database_change", logs)
+        self.assertIn("Sending event: database_change", logs)
 
 
 def suite():
