@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2016, Thomas Scholtes.
 #
@@ -13,10 +12,9 @@
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
 
-from __future__ import division, absolute_import, print_function
 
 import unittest
-from mock import patch
+from unittest.mock import patch
 
 from test.helper import TestHelper,\
     generate_album_info, \
@@ -43,24 +41,24 @@ class MbsyncCliTest(unittest.TestCase, TestHelper):
         album_for_id.return_value = \
             generate_album_info(
                 'album id',
-                [('track id', {'release_track_id': u'release track id'})]
+                [('track id', {'release_track_id': 'release track id'})]
             )
         track_for_id.return_value = \
-            generate_track_info(u'singleton track id',
-                                {'title': u'singleton info'})
+            generate_track_info('singleton track id',
+                                {'title': 'singleton info'})
 
         album_item = Item(
-            album=u'old title',
-            mb_albumid=u'81ae60d4-5b75-38df-903a-db2cfa51c2c6',
-            mb_trackid=u'old track id',
-            mb_releasetrackid=u'release track id',
+            album='old title',
+            mb_albumid='81ae60d4-5b75-38df-903a-db2cfa51c2c6',
+            mb_trackid='old track id',
+            mb_releasetrackid='release track id',
             path=''
         )
         album = self.lib.add_album([album_item])
 
         item = Item(
-            title=u'old title',
-            mb_trackid=u'b8c2cf90-83f9-3b5f-8ccd-31fb866fcf37',
+            title='old title',
+            mb_trackid='b8c2cf90-83f9-3b5f-8ccd-31fb866fcf37',
             path='',
         )
         self.lib.add(item)
@@ -72,25 +70,25 @@ class MbsyncCliTest(unittest.TestCase, TestHelper):
         self.assertIn('Sending event: trackinfo_received', logs)
 
         item.load()
-        self.assertEqual(item.title, u'singleton info')
+        self.assertEqual(item.title, 'singleton info')
 
         album_item.load()
-        self.assertEqual(album_item.title, u'track info')
-        self.assertEqual(album_item.mb_trackid, u'track id')
+        self.assertEqual(album_item.title, 'track info')
+        self.assertEqual(album_item.mb_trackid, 'track id')
 
         album.load()
-        self.assertEqual(album.album, u'album info')
+        self.assertEqual(album.album, 'album info')
 
     def test_message_when_skipping(self):
-        config['format_item'] = u'$artist - $album - $title'
-        config['format_album'] = u'$albumartist - $album'
+        config['format_item'] = '$artist - $album - $title'
+        config['format_album'] = '$albumartist - $album'
 
         # Test album with no mb_albumid.
         # The default format for an album include $albumartist so
         # set that here, too.
         album_invalid = Item(
-            albumartist=u'album info',
-            album=u'album info',
+            albumartist='album info',
+            album='album info',
             path=''
         )
         self.lib.add_album([album_invalid])
@@ -98,27 +96,27 @@ class MbsyncCliTest(unittest.TestCase, TestHelper):
         # default format
         with capture_log('beets.mbsync') as logs:
             self.run_command('mbsync')
-        e = u'mbsync: Skipping album with no mb_albumid: ' + \
-            u'album info - album info'
+        e = 'mbsync: Skipping album with no mb_albumid: ' + \
+            'album info - album info'
         self.assertEqual(e, logs[0])
 
         # custom format
         with capture_log('beets.mbsync') as logs:
             self.run_command('mbsync', '-f', "'$album'")
-        e = u"mbsync: Skipping album with no mb_albumid: 'album info'"
+        e = "mbsync: Skipping album with no mb_albumid: 'album info'"
         self.assertEqual(e, logs[0])
 
         # restore the config
-        config['format_item'] = u'$artist - $album - $title'
-        config['format_album'] = u'$albumartist - $album'
+        config['format_item'] = '$artist - $album - $title'
+        config['format_album'] = '$albumartist - $album'
 
         # Test singleton with no mb_trackid.
         # The default singleton format includes $artist and $album
         # so we need to stub them here
         item_invalid = Item(
-            artist=u'album info',
-            album=u'album info',
-            title=u'old title',
+            artist='album info',
+            album='album info',
+            title='old title',
             path='',
         )
         self.lib.add(item_invalid)
@@ -126,27 +124,27 @@ class MbsyncCliTest(unittest.TestCase, TestHelper):
         # default format
         with capture_log('beets.mbsync') as logs:
             self.run_command('mbsync')
-        e = u'mbsync: Skipping singleton with no mb_trackid: ' + \
-            u'album info - album info - old title'
+        e = 'mbsync: Skipping singleton with no mb_trackid: ' + \
+            'album info - album info - old title'
         self.assertEqual(e, logs[0])
 
         # custom format
         with capture_log('beets.mbsync') as logs:
             self.run_command('mbsync', '-f', "'$title'")
-        e = u"mbsync: Skipping singleton with no mb_trackid: 'old title'"
+        e = "mbsync: Skipping singleton with no mb_trackid: 'old title'"
         self.assertEqual(e, logs[0])
 
     def test_message_when_invalid(self):
-        config['format_item'] = u'$artist - $album - $title'
-        config['format_album'] = u'$albumartist - $album'
+        config['format_item'] = '$artist - $album - $title'
+        config['format_album'] = '$albumartist - $album'
 
         # Test album with invalid mb_albumid.
         # The default format for an album include $albumartist so
         # set that here, too.
         album_invalid = Item(
-            albumartist=u'album info',
-            album=u'album info',
-            mb_albumid=u'a1b2c3d4',
+            albumartist='album info',
+            album='album info',
+            mb_albumid='a1b2c3d4',
             path=''
         )
         self.lib.add_album([album_invalid])
@@ -154,28 +152,28 @@ class MbsyncCliTest(unittest.TestCase, TestHelper):
         # default format
         with capture_log('beets.mbsync') as logs:
             self.run_command('mbsync')
-        e = u'mbsync: Skipping album with invalid mb_albumid: ' + \
-            u'album info - album info'
+        e = 'mbsync: Skipping album with invalid mb_albumid: ' + \
+            'album info - album info'
         self.assertEqual(e, logs[0])
 
         # custom format
         with capture_log('beets.mbsync') as logs:
             self.run_command('mbsync', '-f', "'$album'")
-        e = u"mbsync: Skipping album with invalid mb_albumid: 'album info'"
+        e = "mbsync: Skipping album with invalid mb_albumid: 'album info'"
         self.assertEqual(e, logs[0])
 
         # restore the config
-        config['format_item'] = u'$artist - $album - $title'
-        config['format_album'] = u'$albumartist - $album'
+        config['format_item'] = '$artist - $album - $title'
+        config['format_album'] = '$albumartist - $album'
 
         # Test singleton with invalid mb_trackid.
         # The default singleton format includes $artist and $album
         # so we need to stub them here
         item_invalid = Item(
-            artist=u'album info',
-            album=u'album info',
-            title=u'old title',
-            mb_trackid=u'a1b2c3d4',
+            artist='album info',
+            album='album info',
+            title='old title',
+            mb_trackid='a1b2c3d4',
             path='',
         )
         self.lib.add(item_invalid)
@@ -183,14 +181,14 @@ class MbsyncCliTest(unittest.TestCase, TestHelper):
         # default format
         with capture_log('beets.mbsync') as logs:
             self.run_command('mbsync')
-        e = u'mbsync: Skipping singleton with invalid mb_trackid: ' + \
-            u'album info - album info - old title'
+        e = 'mbsync: Skipping singleton with invalid mb_trackid: ' + \
+            'album info - album info - old title'
         self.assertEqual(e, logs[0])
 
         # custom format
         with capture_log('beets.mbsync') as logs:
             self.run_command('mbsync', '-f', "'$title'")
-        e = u"mbsync: Skipping singleton with invalid mb_trackid: 'old title'"
+        e = "mbsync: Skipping singleton with invalid mb_trackid: 'old title'"
         self.assertEqual(e, logs[0])
 
 
