@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2016, Thomas Scholtes.
 #
@@ -13,10 +12,9 @@
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
 
-from __future__ import division, absolute_import, print_function
 
 import os
-from mock import patch, Mock, ANY
+from unittest.mock import patch, Mock, ANY
 import shutil
 import itertools
 import unittest
@@ -74,22 +72,22 @@ class ItemTypesTest(unittest.TestCase, TestHelper):
         self.register_plugin(RatingPlugin)
         self.config['plugins'] = 'rating'
 
-        item = Item(path=u'apath', artist=u'aaa')
+        item = Item(path='apath', artist='aaa')
         item.add(self.lib)
 
         # Do not match unset values
-        out = self.run_with_output(u'ls', u'rating:1..3')
-        self.assertNotIn(u'aaa', out)
+        out = self.run_with_output('ls', 'rating:1..3')
+        self.assertNotIn('aaa', out)
 
-        self.run_command(u'modify', u'rating=2', u'--yes')
+        self.run_command('modify', 'rating=2', '--yes')
 
         # Match in range
-        out = self.run_with_output(u'ls', u'rating:1..3')
-        self.assertIn(u'aaa', out)
+        out = self.run_with_output('ls', 'rating:1..3')
+        self.assertIn('aaa', out)
 
         # Don't match out of range
-        out = self.run_with_output(u'ls', u'rating:3..5')
-        self.assertNotIn(u'aaa', out)
+        out = self.run_with_output('ls', 'rating:3..5')
+        self.assertNotIn('aaa', out)
 
 
 class ItemWriteTest(unittest.TestCase, TestHelper):
@@ -110,16 +108,16 @@ class ItemWriteTest(unittest.TestCase, TestHelper):
     def test_change_tags(self):
 
         def on_write(item=None, path=None, tags=None):
-            if tags['artist'] == u'XXX':
-                tags['artist'] = u'YYY'
+            if tags['artist'] == 'XXX':
+                tags['artist'] = 'YYY'
 
         self.register_listener('write', on_write)
 
-        item = self.add_item_fixture(artist=u'XXX')
+        item = self.add_item_fixture(artist='XXX')
         item.write()
 
         mediafile = MediaFile(syspath(item.path))
-        self.assertEqual(mediafile.artist, u'YYY')
+        self.assertEqual(mediafile.artist, 'YYY')
 
     def register_listener(self, event, func):
         self.event_listener_plugin.register_listener(event, func)
@@ -195,8 +193,8 @@ class EventsTest(unittest.TestCase, ImportHelper, TestHelper):
         os.makedirs(self.album_path)
 
         metadata = {
-            'artist': u'Tag Artist',
-            'album':  u'Tag Album',
+            'artist': 'Tag Artist',
+            'album':  'Tag Album',
             'albumartist':  None,
             'mb_trackid': None,
             'mb_albumid': None,
@@ -205,7 +203,7 @@ class EventsTest(unittest.TestCase, ImportHelper, TestHelper):
         self.file_paths = []
         for i in range(count):
             metadata['track'] = i + 1
-            metadata['title'] = u'Tag Title Album %d' % (i + 1)
+            metadata['title'] = 'Tag Title Album %d' % (i + 1)
             track_file = bytestring_path('%02d - track.mp3' % (i + 1))
             dest_path = os.path.join(self.album_path, track_file)
             self.__copy_file(dest_path, metadata)
@@ -222,21 +220,21 @@ class EventsTest(unittest.TestCase, ImportHelper, TestHelper):
 
         # Exactly one event should have been imported (for the album).
         # Sentinels do not get emitted.
-        self.assertEqual(logs.count(u'Sending event: import_task_created'), 1)
+        self.assertEqual(logs.count('Sending event: import_task_created'), 1)
 
         logs = [line for line in logs if not line.startswith(
-            u'Sending event:')]
+            'Sending event:')]
         self.assertEqual(logs, [
-            u'Album: {0}'.format(displayable_path(
+            'Album: {}'.format(displayable_path(
                 os.path.join(self.import_dir, b'album'))),
-            u'  {0}'.format(displayable_path(self.file_paths[0])),
-            u'  {0}'.format(displayable_path(self.file_paths[1])),
+            '  {}'.format(displayable_path(self.file_paths[0])),
+            '  {}'.format(displayable_path(self.file_paths[1])),
         ])
 
     def test_import_task_created_with_plugin(self):
         class ToSingletonPlugin(plugins.BeetsPlugin):
             def __init__(self):
-                super(ToSingletonPlugin, self).__init__()
+                super().__init__()
 
                 self.register_listener('import_task_created',
                                        self.import_task_created_event)
@@ -266,13 +264,13 @@ class EventsTest(unittest.TestCase, ImportHelper, TestHelper):
 
         # Exactly one event should have been imported (for the album).
         # Sentinels do not get emitted.
-        self.assertEqual(logs.count(u'Sending event: import_task_created'), 1)
+        self.assertEqual(logs.count('Sending event: import_task_created'), 1)
 
         logs = [line for line in logs if not line.startswith(
-            u'Sending event:')]
+            'Sending event:')]
         self.assertEqual(logs, [
-            u'Singleton: {0}'.format(displayable_path(self.file_paths[0])),
-            u'Singleton: {0}'.format(displayable_path(self.file_paths[1])),
+            'Singleton: {}'.format(displayable_path(self.file_paths[0])),
+            'Singleton: {}'.format(displayable_path(self.file_paths[1])),
         ])
 
 
@@ -280,13 +278,13 @@ class HelpersTest(unittest.TestCase):
 
     def test_sanitize_choices(self):
         self.assertEqual(
-            plugins.sanitize_choices([u'A', u'Z'], (u'A', u'B')), [u'A'])
+            plugins.sanitize_choices(['A', 'Z'], ('A', 'B')), ['A'])
         self.assertEqual(
-            plugins.sanitize_choices([u'A', u'A'], (u'A')), [u'A'])
+            plugins.sanitize_choices(['A', 'A'], ('A')), ['A'])
         self.assertEqual(
-            plugins.sanitize_choices([u'D', u'*', u'A'],
-                                     (u'A', u'B', u'C', u'D')),
-            [u'D', u'B', u'C', u'A'])
+            plugins.sanitize_choices(['D', '*', 'A'],
+                                     ('A', 'B', 'C', 'D')),
+            ['D', 'B', 'C', 'A'])
 
 
 class ListenersTest(unittest.TestCase, TestHelper):
@@ -301,7 +299,7 @@ class ListenersTest(unittest.TestCase, TestHelper):
 
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
-                super(DummyPlugin, self).__init__()
+                super().__init__()
                 self.register_listener('cli_exit', self.dummy)
                 self.register_listener('cli_exit', self.dummy)
 
@@ -326,7 +324,7 @@ class ListenersTest(unittest.TestCase, TestHelper):
 
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
-                super(DummyPlugin, self).__init__()
+                super().__init__()
                 self.foo = Mock(__name__='foo')
                 self.register_listener('event_foo', self.foo)
                 self.bar = Mock(__name__='bar')
@@ -339,8 +337,8 @@ class ListenersTest(unittest.TestCase, TestHelper):
         d.foo.assert_has_calls([])
         d.bar.assert_has_calls([])
 
-        plugins.send('event_foo', var=u"tagada")
-        d.foo.assert_called_once_with(var=u"tagada")
+        plugins.send('event_foo', var="tagada")
+        d.foo.assert_called_once_with(var="tagada")
         d.bar.assert_has_calls([])
 
     @patch('beets.plugins.find_plugins')
@@ -349,13 +347,13 @@ class ListenersTest(unittest.TestCase, TestHelper):
 
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
-                super(DummyPlugin, self).__init__()
+                super().__init__()
                 for i in itertools.count(1):
                     try:
-                        meth = getattr(self, 'dummy{0}'.format(i))
+                        meth = getattr(self, f'dummy{i}')
                     except AttributeError:
                         break
-                    self.register_listener('event{0}'.format(i), meth)
+                    self.register_listener(f'event{i}', meth)
 
             def dummy1(self, foo):
                 test.assertEqual(foo, 5)
@@ -433,19 +431,19 @@ class PromptChoicesTest(TerminalImportSessionSetup, unittest.TestCase,
         """Test the presence of plugin choices on the prompt (album)."""
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
-                super(DummyPlugin, self).__init__()
+                super().__init__()
                 self.register_listener('before_choose_candidate',
                                        self.return_choices)
 
             def return_choices(self, session, task):
-                return [ui.commands.PromptChoice('f', u'Foo', None),
-                        ui.commands.PromptChoice('r', u'baR', None)]
+                return [ui.commands.PromptChoice('f', 'Foo', None),
+                        ui.commands.PromptChoice('r', 'baR', None)]
 
         self.register_plugin(DummyPlugin)
         # Default options + extra choices by the plugin ('Foo', 'Bar')
-        opts = (u'Apply', u'More candidates', u'Skip', u'Use as-is',
-                u'as Tracks', u'Group albums', u'Enter search',
-                u'enter Id', u'aBort') + (u'Foo', u'baR')
+        opts = ('Apply', 'More candidates', 'Skip', 'Use as-is',
+                'as Tracks', 'Group albums', 'Enter search',
+                'enter Id', 'aBort') + ('Foo', 'baR')
 
         self.importer.add_choice(action.SKIP)
         self.importer.run()
@@ -456,19 +454,19 @@ class PromptChoicesTest(TerminalImportSessionSetup, unittest.TestCase,
         """Test the presence of plugin choices on the prompt (singleton)."""
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
-                super(DummyPlugin, self).__init__()
+                super().__init__()
                 self.register_listener('before_choose_candidate',
                                        self.return_choices)
 
             def return_choices(self, session, task):
-                return [ui.commands.PromptChoice('f', u'Foo', None),
-                        ui.commands.PromptChoice('r', u'baR', None)]
+                return [ui.commands.PromptChoice('f', 'Foo', None),
+                        ui.commands.PromptChoice('r', 'baR', None)]
 
         self.register_plugin(DummyPlugin)
         # Default options + extra choices by the plugin ('Foo', 'Bar')
-        opts = (u'Apply', u'More candidates', u'Skip', u'Use as-is',
-                u'Enter search',
-                u'enter Id', u'aBort') + (u'Foo', u'baR')
+        opts = ('Apply', 'More candidates', 'Skip', 'Use as-is',
+                'Enter search',
+                'enter Id', 'aBort') + ('Foo', 'baR')
 
         config['import']['singletons'] = True
         self.importer.add_choice(action.SKIP)
@@ -480,21 +478,21 @@ class PromptChoicesTest(TerminalImportSessionSetup, unittest.TestCase,
         """Test the short letter conflict solving."""
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
-                super(DummyPlugin, self).__init__()
+                super().__init__()
                 self.register_listener('before_choose_candidate',
                                        self.return_choices)
 
             def return_choices(self, session, task):
-                return [ui.commands.PromptChoice('a', u'A foo', None),  # dupe
-                        ui.commands.PromptChoice('z', u'baZ', None),    # ok
-                        ui.commands.PromptChoice('z', u'Zupe', None),   # dupe
-                        ui.commands.PromptChoice('z', u'Zoo', None)]    # dupe
+                return [ui.commands.PromptChoice('a', 'A foo', None),  # dupe
+                        ui.commands.PromptChoice('z', 'baZ', None),    # ok
+                        ui.commands.PromptChoice('z', 'Zupe', None),   # dupe
+                        ui.commands.PromptChoice('z', 'Zoo', None)]    # dupe
 
         self.register_plugin(DummyPlugin)
         # Default options + not dupe extra choices by the plugin ('baZ')
-        opts = (u'Apply', u'More candidates', u'Skip', u'Use as-is',
-                u'as Tracks', u'Group albums', u'Enter search',
-                u'enter Id', u'aBort') + (u'baZ',)
+        opts = ('Apply', 'More candidates', 'Skip', 'Use as-is',
+                'as Tracks', 'Group albums', 'Enter search',
+                'enter Id', 'aBort') + ('baZ',)
         self.importer.add_choice(action.SKIP)
         self.importer.run()
         self.mock_input_options.assert_called_once_with(opts, default='a',
@@ -504,21 +502,21 @@ class PromptChoicesTest(TerminalImportSessionSetup, unittest.TestCase,
         """Test that plugin callbacks are being called upon user choice."""
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
-                super(DummyPlugin, self).__init__()
+                super().__init__()
                 self.register_listener('before_choose_candidate',
                                        self.return_choices)
 
             def return_choices(self, session, task):
-                return [ui.commands.PromptChoice('f', u'Foo', self.foo)]
+                return [ui.commands.PromptChoice('f', 'Foo', self.foo)]
 
             def foo(self, session, task):
                 pass
 
         self.register_plugin(DummyPlugin)
         # Default options + extra choices by the plugin ('Foo', 'Bar')
-        opts = (u'Apply', u'More candidates', u'Skip', u'Use as-is',
-                u'as Tracks', u'Group albums', u'Enter search',
-                u'enter Id', u'aBort') + (u'Foo',)
+        opts = ('Apply', 'More candidates', 'Skip', 'Use as-is',
+                'as Tracks', 'Group albums', 'Enter search',
+                'enter Id', 'aBort') + ('Foo',)
 
         # DummyPlugin.foo() should be called once
         with patch.object(DummyPlugin, 'foo', autospec=True) as mock_foo:
@@ -535,21 +533,21 @@ class PromptChoicesTest(TerminalImportSessionSetup, unittest.TestCase,
         """Test that plugin callbacks that return a value exit the loop."""
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
-                super(DummyPlugin, self).__init__()
+                super().__init__()
                 self.register_listener('before_choose_candidate',
                                        self.return_choices)
 
             def return_choices(self, session, task):
-                return [ui.commands.PromptChoice('f', u'Foo', self.foo)]
+                return [ui.commands.PromptChoice('f', 'Foo', self.foo)]
 
             def foo(self, session, task):
                 return action.SKIP
 
         self.register_plugin(DummyPlugin)
         # Default options + extra choices by the plugin ('Foo', 'Bar')
-        opts = (u'Apply', u'More candidates', u'Skip', u'Use as-is',
-                u'as Tracks', u'Group albums', u'Enter search',
-                u'enter Id', u'aBort') + (u'Foo',)
+        opts = ('Apply', 'More candidates', 'Skip', 'Use as-is',
+                'as Tracks', 'Group albums', 'Enter search',
+                'enter Id', 'aBort') + ('Foo',)
 
         # DummyPlugin.foo() should be called once
         with helper.control_stdin('f\n'):
