@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # This file is part of beets.
 # Copyright 2016, Adrian Sampson.
 #
@@ -15,10 +14,8 @@
 
 """Tests for template engine.
 """
-from __future__ import division, absolute_import, print_function
 
 import unittest
-import six
 from beets.util import functemplate
 
 
@@ -29,17 +26,17 @@ def _normexpr(expr):
     """
     textbuf = []
     for part in expr.parts:
-        if isinstance(part, six.string_types):
+        if isinstance(part, str):
             textbuf.append(part)
         else:
             if textbuf:
-                text = u''.join(textbuf)
+                text = ''.join(textbuf)
                 if text:
                     yield text
                     textbuf = []
             yield part
     if textbuf:
-        text = u''.join(textbuf)
+        text = ''.join(textbuf)
         if text:
             yield text
 
@@ -51,15 +48,15 @@ def _normparse(text):
 
 class ParseTest(unittest.TestCase):
     def test_empty_string(self):
-        self.assertEqual(list(_normparse(u'')), [])
+        self.assertEqual(list(_normparse('')), [])
 
     def _assert_symbol(self, obj, ident):
         """Assert that an object is a Symbol with the given identifier.
         """
         self.assertTrue(isinstance(obj, functemplate.Symbol),
-                        u"not a Symbol: %s" % repr(obj))
+                        "not a Symbol: %s" % repr(obj))
         self.assertEqual(obj.ident, ident,
-                         u"wrong identifier: %s vs. %s" %
+                         "wrong identifier: %s vs. %s" %
                          (repr(obj.ident), repr(ident)))
 
     def _assert_call(self, obj, ident, numargs):
@@ -67,223 +64,223 @@ class ParseTest(unittest.TestCase):
         argument count.
         """
         self.assertTrue(isinstance(obj, functemplate.Call),
-                        u"not a Call: %s" % repr(obj))
+                        "not a Call: %s" % repr(obj))
         self.assertEqual(obj.ident, ident,
-                         u"wrong identifier: %s vs. %s" %
+                         "wrong identifier: %s vs. %s" %
                          (repr(obj.ident), repr(ident)))
         self.assertEqual(len(obj.args), numargs,
-                         u"wrong argument count in %s: %i vs. %i" %
+                         "wrong argument count in %s: %i vs. %i" %
                          (repr(obj.ident), len(obj.args), numargs))
 
     def test_plain_text(self):
-        self.assertEqual(list(_normparse(u'hello world')), [u'hello world'])
+        self.assertEqual(list(_normparse('hello world')), ['hello world'])
 
     def test_escaped_character_only(self):
-        self.assertEqual(list(_normparse(u'$$')), [u'$'])
+        self.assertEqual(list(_normparse('$$')), ['$'])
 
     def test_escaped_character_in_text(self):
-        self.assertEqual(list(_normparse(u'a $$ b')), [u'a $ b'])
+        self.assertEqual(list(_normparse('a $$ b')), ['a $ b'])
 
     def test_escaped_character_at_start(self):
-        self.assertEqual(list(_normparse(u'$$ hello')), [u'$ hello'])
+        self.assertEqual(list(_normparse('$$ hello')), ['$ hello'])
 
     def test_escaped_character_at_end(self):
-        self.assertEqual(list(_normparse(u'hello $$')), [u'hello $'])
+        self.assertEqual(list(_normparse('hello $$')), ['hello $'])
 
     def test_escaped_function_delim(self):
-        self.assertEqual(list(_normparse(u'a $% b')), [u'a % b'])
+        self.assertEqual(list(_normparse('a $% b')), ['a % b'])
 
     def test_escaped_sep(self):
-        self.assertEqual(list(_normparse(u'a $, b')), [u'a , b'])
+        self.assertEqual(list(_normparse('a $, b')), ['a , b'])
 
     def test_escaped_close_brace(self):
-        self.assertEqual(list(_normparse(u'a $} b')), [u'a } b'])
+        self.assertEqual(list(_normparse('a $} b')), ['a } b'])
 
     def test_bare_value_delim_kept_intact(self):
-        self.assertEqual(list(_normparse(u'a $ b')), [u'a $ b'])
+        self.assertEqual(list(_normparse('a $ b')), ['a $ b'])
 
     def test_bare_function_delim_kept_intact(self):
-        self.assertEqual(list(_normparse(u'a % b')), [u'a % b'])
+        self.assertEqual(list(_normparse('a % b')), ['a % b'])
 
     def test_bare_opener_kept_intact(self):
-        self.assertEqual(list(_normparse(u'a { b')), [u'a { b'])
+        self.assertEqual(list(_normparse('a { b')), ['a { b'])
 
     def test_bare_closer_kept_intact(self):
-        self.assertEqual(list(_normparse(u'a } b')), [u'a } b'])
+        self.assertEqual(list(_normparse('a } b')), ['a } b'])
 
     def test_bare_sep_kept_intact(self):
-        self.assertEqual(list(_normparse(u'a , b')), [u'a , b'])
+        self.assertEqual(list(_normparse('a , b')), ['a , b'])
 
     def test_symbol_alone(self):
-        parts = list(_normparse(u'$foo'))
+        parts = list(_normparse('$foo'))
         self.assertEqual(len(parts), 1)
-        self._assert_symbol(parts[0], u"foo")
+        self._assert_symbol(parts[0], "foo")
 
     def test_symbol_in_text(self):
-        parts = list(_normparse(u'hello $foo world'))
+        parts = list(_normparse('hello $foo world'))
         self.assertEqual(len(parts), 3)
-        self.assertEqual(parts[0], u'hello ')
-        self._assert_symbol(parts[1], u"foo")
-        self.assertEqual(parts[2], u' world')
+        self.assertEqual(parts[0], 'hello ')
+        self._assert_symbol(parts[1], "foo")
+        self.assertEqual(parts[2], ' world')
 
     def test_symbol_with_braces(self):
-        parts = list(_normparse(u'hello${foo}world'))
+        parts = list(_normparse('hello${foo}world'))
         self.assertEqual(len(parts), 3)
-        self.assertEqual(parts[0], u'hello')
-        self._assert_symbol(parts[1], u"foo")
-        self.assertEqual(parts[2], u'world')
+        self.assertEqual(parts[0], 'hello')
+        self._assert_symbol(parts[1], "foo")
+        self.assertEqual(parts[2], 'world')
 
     def test_unclosed_braces_symbol(self):
-        self.assertEqual(list(_normparse(u'a ${ b')), [u'a ${ b'])
+        self.assertEqual(list(_normparse('a ${ b')), ['a ${ b'])
 
     def test_empty_braces_symbol(self):
-        self.assertEqual(list(_normparse(u'a ${} b')), [u'a ${} b'])
+        self.assertEqual(list(_normparse('a ${} b')), ['a ${} b'])
 
     def test_call_without_args_at_end(self):
-        self.assertEqual(list(_normparse(u'foo %bar')), [u'foo %bar'])
+        self.assertEqual(list(_normparse('foo %bar')), ['foo %bar'])
 
     def test_call_without_args(self):
-        self.assertEqual(list(_normparse(u'foo %bar baz')), [u'foo %bar baz'])
+        self.assertEqual(list(_normparse('foo %bar baz')), ['foo %bar baz'])
 
     def test_call_with_unclosed_args(self):
-        self.assertEqual(list(_normparse(u'foo %bar{ baz')),
-                         [u'foo %bar{ baz'])
+        self.assertEqual(list(_normparse('foo %bar{ baz')),
+                         ['foo %bar{ baz'])
 
     def test_call_with_unclosed_multiple_args(self):
-        self.assertEqual(list(_normparse(u'foo %bar{bar,bar baz')),
-                         [u'foo %bar{bar,bar baz'])
+        self.assertEqual(list(_normparse('foo %bar{bar,bar baz')),
+                         ['foo %bar{bar,bar baz'])
 
     def test_call_empty_arg(self):
-        parts = list(_normparse(u'%foo{}'))
+        parts = list(_normparse('%foo{}'))
         self.assertEqual(len(parts), 1)
-        self._assert_call(parts[0], u"foo", 1)
+        self._assert_call(parts[0], "foo", 1)
         self.assertEqual(list(_normexpr(parts[0].args[0])), [])
 
     def test_call_single_arg(self):
-        parts = list(_normparse(u'%foo{bar}'))
+        parts = list(_normparse('%foo{bar}'))
         self.assertEqual(len(parts), 1)
-        self._assert_call(parts[0], u"foo", 1)
-        self.assertEqual(list(_normexpr(parts[0].args[0])), [u'bar'])
+        self._assert_call(parts[0], "foo", 1)
+        self.assertEqual(list(_normexpr(parts[0].args[0])), ['bar'])
 
     def test_call_two_args(self):
-        parts = list(_normparse(u'%foo{bar,baz}'))
+        parts = list(_normparse('%foo{bar,baz}'))
         self.assertEqual(len(parts), 1)
-        self._assert_call(parts[0], u"foo", 2)
-        self.assertEqual(list(_normexpr(parts[0].args[0])), [u'bar'])
-        self.assertEqual(list(_normexpr(parts[0].args[1])), [u'baz'])
+        self._assert_call(parts[0], "foo", 2)
+        self.assertEqual(list(_normexpr(parts[0].args[0])), ['bar'])
+        self.assertEqual(list(_normexpr(parts[0].args[1])), ['baz'])
 
     def test_call_with_escaped_sep(self):
-        parts = list(_normparse(u'%foo{bar$,baz}'))
+        parts = list(_normparse('%foo{bar$,baz}'))
         self.assertEqual(len(parts), 1)
-        self._assert_call(parts[0], u"foo", 1)
-        self.assertEqual(list(_normexpr(parts[0].args[0])), [u'bar,baz'])
+        self._assert_call(parts[0], "foo", 1)
+        self.assertEqual(list(_normexpr(parts[0].args[0])), ['bar,baz'])
 
     def test_call_with_escaped_close(self):
-        parts = list(_normparse(u'%foo{bar$}baz}'))
+        parts = list(_normparse('%foo{bar$}baz}'))
         self.assertEqual(len(parts), 1)
-        self._assert_call(parts[0], u"foo", 1)
-        self.assertEqual(list(_normexpr(parts[0].args[0])), [u'bar}baz'])
+        self._assert_call(parts[0], "foo", 1)
+        self.assertEqual(list(_normexpr(parts[0].args[0])), ['bar}baz'])
 
     def test_call_with_symbol_argument(self):
-        parts = list(_normparse(u'%foo{$bar,baz}'))
+        parts = list(_normparse('%foo{$bar,baz}'))
         self.assertEqual(len(parts), 1)
-        self._assert_call(parts[0], u"foo", 2)
+        self._assert_call(parts[0], "foo", 2)
         arg_parts = list(_normexpr(parts[0].args[0]))
         self.assertEqual(len(arg_parts), 1)
-        self._assert_symbol(arg_parts[0], u"bar")
-        self.assertEqual(list(_normexpr(parts[0].args[1])), [u"baz"])
+        self._assert_symbol(arg_parts[0], "bar")
+        self.assertEqual(list(_normexpr(parts[0].args[1])), ["baz"])
 
     def test_call_with_nested_call_argument(self):
-        parts = list(_normparse(u'%foo{%bar{},baz}'))
+        parts = list(_normparse('%foo{%bar{},baz}'))
         self.assertEqual(len(parts), 1)
-        self._assert_call(parts[0], u"foo", 2)
+        self._assert_call(parts[0], "foo", 2)
         arg_parts = list(_normexpr(parts[0].args[0]))
         self.assertEqual(len(arg_parts), 1)
-        self._assert_call(arg_parts[0], u"bar", 1)
-        self.assertEqual(list(_normexpr(parts[0].args[1])), [u"baz"])
+        self._assert_call(arg_parts[0], "bar", 1)
+        self.assertEqual(list(_normexpr(parts[0].args[1])), ["baz"])
 
     def test_nested_call_with_argument(self):
-        parts = list(_normparse(u'%foo{%bar{baz}}'))
+        parts = list(_normparse('%foo{%bar{baz}}'))
         self.assertEqual(len(parts), 1)
-        self._assert_call(parts[0], u"foo", 1)
+        self._assert_call(parts[0], "foo", 1)
         arg_parts = list(_normexpr(parts[0].args[0]))
         self.assertEqual(len(arg_parts), 1)
-        self._assert_call(arg_parts[0], u"bar", 1)
-        self.assertEqual(list(_normexpr(arg_parts[0].args[0])), [u'baz'])
+        self._assert_call(arg_parts[0], "bar", 1)
+        self.assertEqual(list(_normexpr(arg_parts[0].args[0])), ['baz'])
 
     def test_sep_before_call_two_args(self):
-        parts = list(_normparse(u'hello, %foo{bar,baz}'))
+        parts = list(_normparse('hello, %foo{bar,baz}'))
         self.assertEqual(len(parts), 2)
-        self.assertEqual(parts[0], u'hello, ')
-        self._assert_call(parts[1], u"foo", 2)
-        self.assertEqual(list(_normexpr(parts[1].args[0])), [u'bar'])
-        self.assertEqual(list(_normexpr(parts[1].args[1])), [u'baz'])
+        self.assertEqual(parts[0], 'hello, ')
+        self._assert_call(parts[1], "foo", 2)
+        self.assertEqual(list(_normexpr(parts[1].args[0])), ['bar'])
+        self.assertEqual(list(_normexpr(parts[1].args[1])), ['baz'])
 
     def test_sep_with_symbols(self):
-        parts = list(_normparse(u'hello,$foo,$bar'))
+        parts = list(_normparse('hello,$foo,$bar'))
         self.assertEqual(len(parts), 4)
-        self.assertEqual(parts[0], u'hello,')
-        self._assert_symbol(parts[1], u"foo")
-        self.assertEqual(parts[2], u',')
-        self._assert_symbol(parts[3], u"bar")
+        self.assertEqual(parts[0], 'hello,')
+        self._assert_symbol(parts[1], "foo")
+        self.assertEqual(parts[2], ',')
+        self._assert_symbol(parts[3], "bar")
 
     def test_newline_at_end(self):
-        parts = list(_normparse(u'foo\n'))
+        parts = list(_normparse('foo\n'))
         self.assertEqual(len(parts), 1)
-        self.assertEqual(parts[0], u'foo\n')
+        self.assertEqual(parts[0], 'foo\n')
 
 
 class EvalTest(unittest.TestCase):
     def _eval(self, template):
         values = {
-            u'foo': u'bar',
-            u'baz': u'BaR',
+            'foo': 'bar',
+            'baz': 'BaR',
         }
         functions = {
-            u'lower': six.text_type.lower,
-            u'len': len,
+            'lower': str.lower,
+            'len': len,
         }
         return functemplate.Template(template).substitute(values, functions)
 
     def test_plain_text(self):
-        self.assertEqual(self._eval(u"foo"), u"foo")
+        self.assertEqual(self._eval("foo"), "foo")
 
     def test_subtitute_value(self):
-        self.assertEqual(self._eval(u"$foo"), u"bar")
+        self.assertEqual(self._eval("$foo"), "bar")
 
     def test_subtitute_value_in_text(self):
-        self.assertEqual(self._eval(u"hello $foo world"), u"hello bar world")
+        self.assertEqual(self._eval("hello $foo world"), "hello bar world")
 
     def test_not_subtitute_undefined_value(self):
-        self.assertEqual(self._eval(u"$bar"), u"$bar")
+        self.assertEqual(self._eval("$bar"), "$bar")
 
     def test_function_call(self):
-        self.assertEqual(self._eval(u"%lower{FOO}"), u"foo")
+        self.assertEqual(self._eval("%lower{FOO}"), "foo")
 
     def test_function_call_with_text(self):
-        self.assertEqual(self._eval(u"A %lower{FOO} B"), u"A foo B")
+        self.assertEqual(self._eval("A %lower{FOO} B"), "A foo B")
 
     def test_nested_function_call(self):
-        self.assertEqual(self._eval(u"%lower{%lower{FOO}}"), u"foo")
+        self.assertEqual(self._eval("%lower{%lower{FOO}}"), "foo")
 
     def test_symbol_in_argument(self):
-        self.assertEqual(self._eval(u"%lower{$baz}"), u"bar")
+        self.assertEqual(self._eval("%lower{$baz}"), "bar")
 
     def test_function_call_exception(self):
-        res = self._eval(u"%lower{a,b,c,d,e}")
-        self.assertTrue(isinstance(res, six.string_types))
+        res = self._eval("%lower{a,b,c,d,e}")
+        self.assertTrue(isinstance(res, str))
 
     def test_function_returning_integer(self):
-        self.assertEqual(self._eval(u"%len{foo}"), u"3")
+        self.assertEqual(self._eval("%len{foo}"), "3")
 
     def test_not_subtitute_undefined_func(self):
-        self.assertEqual(self._eval(u"%bar{}"), u"%bar{}")
+        self.assertEqual(self._eval("%bar{}"), "%bar{}")
 
     def test_not_subtitute_func_with_no_args(self):
-        self.assertEqual(self._eval(u"%lower"), u"%lower")
+        self.assertEqual(self._eval("%lower"), "%lower")
 
     def test_function_call_with_empty_arg(self):
-        self.assertEqual(self._eval(u"%len{}"), u"0")
+        self.assertEqual(self._eval("%len{}"), "0")
 
 
 def suite():
